@@ -3,16 +3,15 @@ from __future__ import annotations
 import math
 import sys
 
-from serialtbx.detector import iterate_detector_at_level
+import dials.util
+from dials.util.options import OptionParser
 
 from libtbx.phil import parse
 from libtbx.test_utils import approx_equal
 from scitbx.array_family import flex
 from scitbx.math.superpose import least_squares_fit
 from scitbx.matrix import col
-
-import dials.util
-from dials.util.options import OptionParser
+from serialtbx.detector import iterate_detector_at_level
 
 import dxtbx.util
 from dxtbx.model.experiment_list import ExperimentListFactory
@@ -92,10 +91,9 @@ def run(args=None):
             "Reference detector must be at least %d panels long given the panel list"
             % (max_p_id + 1)
         )
-        assert max_p_id < len(
-            moving
-        ), "Moving detector must be at least %d panels long given the panel list" % (
-            max_p_id + 1
+        assert max_p_id < len(moving), (
+            "Moving detector must be at least %d panels long given the panel list"
+            % (max_p_id + 1)
         )
         panel_ids = params.panel_list
 
