@@ -2,7 +2,6 @@
 standard used in electron microscopy
 (http://www.ccpem.ac.uk/mrc_format/mrc2014.php)"""
 
-
 from __future__ import annotations
 
 import logging
@@ -39,11 +38,19 @@ class FormatMRC(Format):
 
         with mrcfile.open(self._image_file, header_only=True) as mrc:
             h = mrc.header
-            xh = mrc.extended_header
+            try:
+                xh = mrc.indexed_extended_header
+            except AttributeError:
+                # mrcfile<1.5.0 does not have indexed_extended_header
+                xh = mrc.extended_header
 
         self._header_dictionary = self._unpack_header(h)
-        if len(xh) > 0:
-            self._extend_header(xh)
+        if len(xh) == int(h["nz"]):
+            try:
+                self._extend_header(xh)
+            except ValueError:
+                # Ignore problematic extended headers
+                pass
 
     @staticmethod
     def _unpack_header(header):
@@ -56,14 +63,16 @@ class FormatMRC(Format):
 
         # For image stacks, NX==MX etc. should always be true. Assert this
         # to ensure we fail on an MRC file of the wrong type.
-        assert hd["nx"] == hd["mx"]
-        assert hd["ny"] == hd["my"]
-        assert hd["nz"] == hd["mz"]
+        try:
+            assert hd["nx"] == hd["mx"]
+            assert hd["ny"] == hd["my"]
+            assert (hd["nz"] == hd["mz"]) or (hd["mz"] == 1)
+        except AssertionError:
+            raise ValueError("Unexpected data size values in the header")
 
         return hd
 
     def _extend_header(self, xh):
-
         # Extensions from FEI headers only
         if not self._header_dictionary["exttyp"].startswith(b"FEI"):
             return
@@ -73,9 +82,11 @@ class FormatMRC(Format):
         self._header_dictionary["tilt_axis"] = xh["Tilt axis angle"][0]
         self._header_dictionary["pixelSpacing"] = xh["Pixel size X"][0]
         assert self._header_dictionary["pixelSpacing"] == xh["Pixel size Y"][0]
+        if self._header_dictionary["pixelSpacing"] == 0:
+            raise ValueError("Incorrect extended header")
         self._header_dictionary["acceleratingVoltage"] = xh["HT"][0]
         self._header_dictionary["camera"] = xh["Camera name"][0]
-        self._header_dictionary["binning"] = xh["Binning Width"][0]
+        self._header_dictionary["binning"] = max(xh["Binning Width"][0], 1)
         self._header_dictionary["noiseReduction"] = xh["Ceta noise reduction"][0]
         if b"Ceta" in self._header_dictionary["camera"]:
             # Does this ever differ from the Binning Width from the header?
@@ -262,7 +273,6 @@ class FormatMRCimages(FormatMRC):
         return ScanFactory.make_scan((index, index), exposure, oscillation, {index: 0})
 
     def get_raw_data(self):
-
         with mrcfile.open(self._image_file) as mrc:
             image = flex.double(mrc.data.astype("double"))
 
@@ -306,7 +316,6 @@ class FormatMRCstack(FormatMultiImage, FormatMRC):
         return Format.get_image_file(self)
 
     def get_raw_data(self, index):
-
         # Note MRC files use z, y, x ordering
         with mrcfile.mmap(self._image_file) as mrc:
             image = flex.double(mrc.data[index, ...].astype("double"))
