@@ -11,9 +11,11 @@ import operator
 import os
 import pickle
 import sys
-from typing import Any, Callable, Generator, Iterable
+from collections.abc import Callable, Generator, Iterable
+from typing import Any
 
 import natsort
+from tqdm import tqdm
 
 import dxtbx
 from dxtbx.format.Format import Format
@@ -197,9 +199,7 @@ class ExperimentListDict:
         # Basic check: This is a dict-like object. This can happen if e.g. we
         # were passed a DataBlock list instead of an ExperimentList dictionary
         if isinstance(obj, list) or not hasattr(obj, "get"):
-            raise InvalidExperimentListError(
-                "Expected dictionary, not {}".format(type(obj))
-            )
+            raise InvalidExperimentListError(f"Expected dictionary, not {type(obj)}")
 
         self._obj = copy.deepcopy(obj)
         self._check_format = check_format
@@ -664,6 +664,9 @@ class ExperimentListFactory:
         """Create a list of data blocks from a list of directory or file names."""
         experiments = ExperimentList()
 
+        # Cast filenames to a list from whatever iterator they are
+        filenames = list(filenames)
+
         # Process each file given by this path list
         to_process = _openingpathiterator(filenames)
         find_format = FormatChecker()
@@ -671,7 +674,13 @@ class ExperimentListFactory:
         format_groups = collections.defaultdict(list)
         if format_kwargs is None:
             format_kwargs = {}
-        for filename in to_process:
+
+        if os.isatty and len(filenames) > 1 and "DIALS_NOBANNER" not in os.environ:
+            filename_iter = tqdm(to_process, total=len(filenames), file=sys.stdout)
+        else:
+            filename_iter = to_process
+
+        for filename in filename_iter:
             # We now have a file, pre-opened by Format.open_file (therefore
             # cached). Determine its type, and prepare to put into a group
             format_class = find_format.find_format(filename)
