@@ -1,18 +1,19 @@
 from __future__ import annotations
 
-import procrunner
+from dxtbx.command_line import print_header
 
 
-def test_print_header(dials_data):
+def test_print_header(dials_data, capsys):
     screen = dials_data("thaumatin_eiger_screen", pathlib=True)
     master = screen / "Therm_6_1_master.h5"
-    result = procrunner.run(["dxtbx.print_header", master])
-    assert not result.returncode and not result.stderr
+    print_header.run([str(master)])
 
     expected_output = [
         f"=== {master} ===",
         "Using header reader: FormatNXmxDLS16M",
     ]
 
+    captured = capsys.readouterr()
+    assert not captured.err
     for record in expected_output:
-        assert record.strip().encode("latin-1") in result.stdout, record
+        assert record.strip() in captured.out, record
